@@ -1,7 +1,10 @@
 #!/usr/bin/env python
 """Run Cython with custom options."""
+
 import os
+import pathlib
 import sys
+
 from Cython.Compiler.Main import main as cython_main
 
 
@@ -10,14 +13,15 @@ def cythonize(args=None):
     if args is None:
         argv = sys.argv[:]
     else:
-        argv = [os.path.abspath(__file__), *args]
+        arg0 = str(pathlib.Path(__file__).resolve())
+        argv = [arg0, *args]
 
-    if '--cleanup' not in argv:
-        argv[1:1] = ['--cleanup', '3']
-    if '--3str' not in argv:
-        argv[1:1] = ['--3str']
+    if "--cleanup" not in argv:
+        argv[1:1] = ["--cleanup", "3"]
+    if "--3str" not in argv:
+        argv[1:1] = ["--3str"]
 
-    cwd = os.getcwd()
+    cwd = pathlib.Path.cwd()
     sys_argv = sys.argv[:]
     try:
         sys.argv[:] = argv
@@ -35,12 +39,11 @@ def main():
     """Entry-point to run Cython with custom options."""
     args = sys.argv[1:]
     if not args:
-        appdir = os.path.dirname(os.path.abspath(__file__))
-        topdir = os.path.dirname(appdir)
-        source = os.path.join('src', 'mpi4py', 'MPI.pyx')
-        target = os.path.join('src', 'mpi4py', 'MPI.c')
-        args += ['--working', topdir]
-        args += [source, '--output-file', target]
+        topdir = pathlib.Path(__file__).resolve().parent.parent
+        source = pathlib.Path() / "src" / "mpi4py" / "MPI.pyx"
+        target = pathlib.Path() / "src" / "mpi4py" / "MPI.c"
+        args += ["--working", str(topdir)]
+        args += [str(source), "--output-file", str(target)]
     sys.exit(cythonize(args))
 
 
