@@ -1,6 +1,7 @@
-from mpi4py import MPI
 import helloworld as hw
 
+from mpi4py import MPI
+
 null = MPI.COMM_NULL
 fnull = null.py2f()
 hw.sayhello(fnull)
@@ -10,8 +11,8 @@ fcomm = comm.py2f()
 hw.sayhello(fcomm)
 
 try:
-    hw.sayhello(list())
-except:
+    hw.sayhello(None)
+except (AttributeError, TypeError):
     pass
 else:
     assert 0, "exception not raised"
