@@ -1,34 +1,41 @@
-from mpi4py import MPI
-import mpiunittest as unittest
-import arrayimpl
-
 from functools import reduce
-prod = lambda sequence,start=1: reduce(lambda x, y: x*y, sequence, start)
+from operator import mul
+
+import arrayimpl
+import mpiunittest as unittest
+
+from mpi4py import MPI
+
+
+def prod(sequence, start=1):
+    return reduce(mul, sequence, start)
+
 
 def skip_op(typecode, op):
-    if typecode in '?':
+    if typecode == "?":
         return True
-    if typecode in 'FDG':
+    if typecode in "FDG":
         if op in (MPI.MAX, MPI.MIN):
             return True
     return False
 
+
 def maxvalue(a):
     try:
         typecode = a.typecode
     except AttributeError:
         typecode = a.dtype.char
-    if typecode == ('f'):
+    if typecode == ("f"):
         return 1e30
-    elif typecode == ('d'):
+    elif typecode == ("d"):
         return 1e300
     else:
         return 2 ** (a.itemsize * 7) - 1
 
 
-@unittest.skipMPI('msmpi(<8.1.0)')
+@unittest.skipMPI("msmpi(<8.1.0)")
 class BaseTestCCOBuf:
-
+    #
     COMM = MPI.COMM_NULL
 
     def testBarrier(self):
@@ -43,7 +50,7 @@ class BaseTestCCOBuf:
                 if rank == root:
                     buf = array(root, typecode, root)
                 else:
-                    buf = array(  -1, typecode, root)
+                    buf = array(-1, typecode, root)
                 self.COMM.Ibcast(buf.as_mpi(), root=root).Wait()
                 for value in buf:
                     self.assertEqual(value, check)
@@ -54,13 +61,14 @@ class BaseTestCCOBuf:
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                sbuf = array(root, typecode, root+1)
+                sbuf = array(root, typecode, root + 1)
                 if rank == root:
-                    rbuf = array(-1, typecode, (size,root+1))
+                    rbuf = array(-1, typecode, (size, root + 1))
                 else:
                     rbuf = array([], typecode)
-                self.COMM.Igather(sbuf.as_mpi(), rbuf.as_mpi(),
-                                  root=root).Wait()
+                self.COMM.Igather(
+                    sbuf.as_mpi(), rbuf.as_mpi(), root=root
+                ).Wait()
                 if rank == root:
                     for value in rbuf.flat:
                         self.assertEqual(value, check)
@@ -76,32 +84,35 @@ class BaseTestCCOBuf:
                     sbuf = array(root, typecode, (size, size))
                 else:
                     sbuf = array([], typecode)
-                self.COMM.Iscatter(sbuf.as_mpi(), rbuf.as_mpi(),
-                                   root=root).Wait()
+                self.COMM.Iscatter(
+                    sbuf.as_mpi(), rbuf.as_mpi(), root=root
+                ).Wait()
                 for value in rbuf:
                     self.assertEqual(value, check)
 
     def testAllgather(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                sbuf = array(root, typecode, root+1)
-                rbuf = array(  -1, typecode, (size, root+1))
+                sbuf = array(root, typecode, root + 1)
+                rbuf = array(-1, typecode, (size, root + 1))
                 self.COMM.Iallgather(sbuf.as_mpi(), rbuf.as_mpi()).Wait()
                 for value in rbuf.flat:
                     self.assertEqual(value, check)
 
     def testAlltoall(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                sbuf = array(root, typecode, (size, root+1))
-                rbuf = array(  -1, typecode, (size, root+1))
-                self.COMM.Ialltoall(sbuf.as_mpi(), rbuf.as_mpi_c(root+1)).Wait()
+                sbuf = array(root, typecode, (size, root + 1))
+                rbuf = array(-1, typecode, (size, root + 1))
+                self.COMM.Ialltoall(
+                    sbuf.as_mpi(), rbuf.as_mpi_c(root + 1)
+                ).Wait()
                 for value in rbuf.flat:
                     self.assertEqual(value, check)
 
@@ -110,15 +121,17 @@ class BaseTestCCOBuf:
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.PROD, MPI.MAX, MPI.MIN):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 for root in range(size):
                     sbuf = array(range(size), typecode)
                     rbuf = array(-1, typecode, size)
-                    self.COMM.Ireduce(sbuf.as_mpi(),
-                                      rbuf.as_mpi(),
-                                      op, root).Wait()
+                    self.COMM.Ireduce(
+                        sbuf.as_mpi(), rbuf.as_mpi(), op, root
+                    ).Wait()
                     max_val = maxvalue(rbuf)
                     for i, value in enumerate(rbuf):
                         if rank != root:
@@ -127,9 +140,9 @@ class BaseTestCCOBuf:
                             continue
                         if op == MPI.SUM:
                             if (i * size) < max_val:
-                                self.assertAlmostEqual(value, i*size)
+                                self.assertAlmostEqual(value, i * size)
                         elif op == MPI.PROD:
-                            if (i ** size) < max_val:
+                            if (i**size) < max_val:
                                 self.assertAlmostEqual(value, i**size)
                         elif op == MPI.MAX:
                             self.assertEqual(value, i)
@@ -138,71 +151,73 @@ class BaseTestCCOBuf:
 
     def testAllreduce(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.MAX, MPI.MIN, MPI.PROD):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 sbuf = array(range(size), typecode)
                 rbuf = array(0, typecode, size)
-                self.COMM.Iallreduce(sbuf.as_mpi(),
-                                     rbuf.as_mpi(),
-                                     op).Wait()
+                self.COMM.Iallreduce(sbuf.as_mpi(), rbuf.as_mpi(), op).Wait()
                 max_val = maxvalue(rbuf)
                 for i, value in enumerate(rbuf):
                     if op == MPI.SUM:
                         if (i * size) < max_val:
-                            self.assertAlmostEqual(value, i*size)
+                            self.assertAlmostEqual(value, i * size)
                     elif op == MPI.PROD:
-                        if (i ** size) < max_val:
+                        if (i**size) < max_val:
                             self.assertAlmostEqual(value, i**size)
                     elif op == MPI.MAX:
                         self.assertEqual(value, i)
                     elif op == MPI.MIN:
                         self.assertEqual(value, i)
 
-    @unittest.skipMPI('openmpi(<=1.8.3)')
+    @unittest.skipMPI("openmpi(<=1.8.3)")
     def testReduceScatter(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.MAX, MPI.MIN, MPI.PROD):
-                if skip_op(typecode, op): continue
-                rcnt = list(range(1,size+1))
-                sbuf = array([rank+1]*sum(rcnt), typecode)
-                rbuf = array(-1, typecode, rank+1)
-                self.COMM.Ireduce_scatter(sbuf.as_mpi(),
-                                          rbuf.as_mpi(),
-                                          None, op).Wait()
+                if skip_op(typecode, op):
+                    continue
+                rcnt = list(range(1, size + 1))
+                sbuf = array([rank + 1] * sum(rcnt), typecode)
+                rbuf = array(-1, typecode, rank + 1)
+                self.COMM.Ireduce_scatter(
+                    sbuf.as_mpi(), rbuf.as_mpi(), None, op
+                ).Wait()
                 max_val = maxvalue(rbuf)
-                for i, value in enumerate(rbuf):
+                for value in rbuf:
                     if op == MPI.SUM:
-                        redval = sum(range(size))+size
+                        redval = sum(range(size)) + size
                         if redval < max_val:
                             self.assertAlmostEqual(value, redval)
                     elif op == MPI.PROD:
-                        redval = prod(range(1,size+1))
+                        redval = prod(range(1, size + 1))
                         if redval < max_val:
                             self.assertAlmostEqual(value, redval)
                     elif op == MPI.MAX:
                         self.assertEqual(value, size)
                     elif op == MPI.MIN:
                         self.assertEqual(value, 1)
-                rbuf = array(-1, typecode, rank+1)
-                self.COMM.Ireduce_scatter(sbuf.as_mpi(),
-                                          rbuf.as_mpi(),
-                                          rcnt, op).Wait()
+                rbuf = array(-1, typecode, rank + 1)
+                self.COMM.Ireduce_scatter(
+                    sbuf.as_mpi(), rbuf.as_mpi(), rcnt, op
+                ).Wait()
                 max_val = maxvalue(rbuf)
-                for i, value in enumerate(rbuf):
+                for value in rbuf:
                     if op == MPI.SUM:
-                        redval = sum(range(size))+size
+                        redval = sum(range(size)) + size
                         if redval < max_val:
                             self.assertAlmostEqual(value, redval)
                     elif op == MPI.PROD:
-                        redval = prod(range(1,size+1))
+                        redval = prod(range(1, size + 1))
                         if redval < max_val:
                             self.assertAlmostEqual(value, redval)
                     elif op == MPI.MAX:
@@ -215,24 +230,27 @@ class BaseTestCCOBuf:
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.MAX, MPI.MIN, MPI.PROD):
-                if skip_op(typecode, op): continue
-                for rcnt in range(1, size+1):
-                    sbuf = array([rank]*rcnt*size, typecode)
+                if skip_op(typecode, op):
+                    continue
+                for rcnt in range(1, size + 1):
+                    sbuf = array([rank] * rcnt * size, typecode)
                     rbuf = array(-1, typecode, rcnt)
                     if op == MPI.PROD:
-                        sbuf = array([rank+1]*rcnt*size, typecode)
-                    self.COMM.Ireduce_scatter_block(sbuf.as_mpi(),
-                                                    rbuf.as_mpi(),
-                                                    op).Wait()
+                        sbuf = array([rank + 1] * rcnt * size, typecode)
+                    self.COMM.Ireduce_scatter_block(
+                        sbuf.as_mpi(), rbuf.as_mpi(), op
+                    ).Wait()
                     max_val = maxvalue(rbuf)
-                    v_sum  = (size*(size-1))/2
+                    v_sum = (size * (size - 1)) / 2
                     v_prod = 1
-                    for i in range(1,size+1): v_prod *= i
-                    v_max  = size-1
-                    v_min  = 0
-                    for i, value in enumerate(rbuf):
+                    for i in range(1, size + 1):
+                        v_prod *= i
+                    v_max = size - 1
+                    v_min = 0
+                    for value in rbuf:
                         if op == MPI.SUM:
                             if v_sum <= max_val:
                                 self.assertAlmostEqual(value, v_sum)
@@ -250,14 +268,14 @@ class BaseTestCCOBuf:
         # --
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.PROD, MPI.MAX, MPI.MIN):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 sbuf = array(range(size), typecode)
                 rbuf = array(0, typecode, size)
-                self.COMM.Iscan(sbuf.as_mpi(),
-                                rbuf.as_mpi(),
-                                op).Wait()
+                self.COMM.Iscan(sbuf.as_mpi(), rbuf.as_mpi(), op).Wait()
                 max_val = maxvalue(rbuf)
                 for i, value in enumerate(rbuf):
                     if op == MPI.SUM:
@@ -271,20 +289,20 @@ class BaseTestCCOBuf:
                     elif op == MPI.MIN:
                         self.assertEqual(value, i)
 
-    @unittest.skipMPI('openmpi(<=1.8.1)')
+    @unittest.skipMPI("openmpi(<=1.8.1)")
     def testExscan(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.PROD, MPI.MAX, MPI.MIN):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 sbuf = array(range(size), typecode)
                 rbuf = array(0, typecode, size)
-                self.COMM.Iexscan(sbuf.as_mpi(),
-                                  rbuf.as_mpi(),
-                                  op).Wait()
+                self.COMM.Iexscan(sbuf.as_mpi(), rbuf.as_mpi(), op).Wait()
                 if rank == 1:
                     for i, value in enumerate(rbuf):
                         self.assertEqual(value, i)
@@ -295,8 +313,8 @@ class BaseTestCCOBuf:
                             if (i * rank) < max_val:
                                 self.assertAlmostEqual(value, i * rank)
                         elif op == MPI.PROD:
-                            if (i ** rank) < max_val:
-                                self.assertAlmostEqual(value, i ** rank)
+                            if (i**rank) < max_val:
+                                self.assertAlmostEqual(value, i**rank)
                         elif op == MPI.MAX:
                             self.assertEqual(value, i)
                         elif op == MPI.MIN:
@@ -341,23 +359,24 @@ class BaseTestCCOBuf:
                         self.assertEqual(value, check)
 
 
-@unittest.skipMPI('msmpi(<8.1.0)')
+@unittest.skipMPI("msmpi(<8.1.0)")
 class BaseTestCCOBufInplace:
-
+    #
     def testGather(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                count = root+3
+                count = root + 3
                 if rank == root:
                     sbuf = MPI.IN_PLACE
                     buf = array(-1, typecode, (size, count))
-                    #buf.flat[(rank*count):((rank+1)*count)] = \
+                    # buf.flat[(rank*count):((rank+1)*count)] = \
                     #    array(root, typecode, count)
-                    s, e = rank*count, (rank+1)*count
-                    for i in range(s, e): buf.flat[i] = check
+                    s, e = rank * count, (rank + 1) * count
+                    for i in range(s, e):
+                        buf.flat[i] = check
                     rbuf = buf.as_mpi()
                 else:
                     buf = array(root, typecode, count)
@@ -372,7 +391,7 @@ class BaseTestCCOBufInplace:
                 for value in buf.flat:
                     self.assertEqual(value, check)
 
-    @unittest.skipMPI('msmpi(==10.0.0)')
+    @unittest.skipMPI("msmpi(==10.0.0)")
     def testScatter(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -397,7 +416,6 @@ class BaseTestCCOBufInplace:
                     for value in buf.flat:
                         self.assertEqual(value, check)
 
-
     def testAllgather(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
@@ -405,8 +423,9 @@ class BaseTestCCOBufInplace:
             for count in range(1, 10):
                 check = arrayimpl.scalar(count)
                 buf = array(-1, typecode, (size, count))
-                s, e = rank*count, (rank+1)*count
-                for i in range(s, e): buf.flat[i] = check
+                s, e = rank * count, (rank + 1) * count
+                for i in range(s, e):
+                    buf.flat[i] = check
                 self.COMM.Iallgather(MPI.IN_PLACE, buf.as_mpi()).Wait()
                 for value in buf.flat:
                     self.assertEqual(value, check)
@@ -419,16 +438,18 @@ class BaseTestCCOBufInplace:
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.PROD, MPI.MAX, MPI.MIN):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 for root in range(size):
                     if rank == root:
-                        buf  = array(range(size), typecode)
+                        buf = array(range(size), typecode)
                         sbuf = MPI.IN_PLACE
                         rbuf = buf.as_mpi()
                     else:
-                        buf  = array(range(size), typecode)
+                        buf = array(range(size), typecode)
                         buf2 = array(range(size), typecode)
                         sbuf = buf.as_mpi()
                         rbuf = buf2.as_mpi()
@@ -438,9 +459,9 @@ class BaseTestCCOBufInplace:
                         for i, value in enumerate(buf):
                             if op == MPI.SUM:
                                 if (i * size) < max_val:
-                                    self.assertAlmostEqual(value, i*size)
+                                    self.assertAlmostEqual(value, i * size)
                             elif op == MPI.PROD:
-                                if (i ** size) < max_val:
+                                if (i**size) < max_val:
                                     self.assertAlmostEqual(value, i**size)
                             elif op == MPI.MAX:
                                 self.assertEqual(value, i)
@@ -449,12 +470,14 @@ class BaseTestCCOBufInplace:
 
     def testAllreduce(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.MAX, MPI.MIN, MPI.PROD):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 buf = array(range(size), typecode)
                 sbuf = MPI.IN_PLACE
                 rbuf = buf.as_mpi()
@@ -463,37 +486,39 @@ class BaseTestCCOBufInplace:
                 for i, value in enumerate(buf):
                     if op == MPI.SUM:
                         if (i * size) < max_val:
-                            self.assertAlmostEqual(value, i*size)
+                            self.assertAlmostEqual(value, i * size)
                     elif op == MPI.PROD:
-                        if (i ** size) < max_val:
+                        if (i**size) < max_val:
                             self.assertAlmostEqual(value, i**size)
                     elif op == MPI.MAX:
                         self.assertEqual(value, i)
                     elif op == MPI.MIN:
                         self.assertEqual(value, i)
 
-    @unittest.skipMPI('openmpi(<=1.8.6)')
+    @unittest.skipMPI("openmpi(<=1.8.6)")
     def testReduceScatterBlock(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.MAX, MPI.MIN, MPI.PROD):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 for rcnt in range(size):
                     if op == MPI.PROD:
-                        rbuf = array([rank+1]*rcnt*size, typecode)
+                        rbuf = array([rank + 1] * rcnt * size, typecode)
                     else:
-                        rbuf = array([rank]*rcnt*size, typecode)
-                    self.COMM.Ireduce_scatter_block(MPI.IN_PLACE,
-                                                    rbuf.as_mpi(),
-                                                    op).Wait()
+                        rbuf = array([rank] * rcnt * size, typecode)
+                    self.COMM.Ireduce_scatter_block(
+                        MPI.IN_PLACE, rbuf.as_mpi(), op
+                    ).Wait()
                     max_val = maxvalue(rbuf)
                     for i, value in enumerate(rbuf):
                         if i >= rcnt:
                             if op == MPI.PROD:
-                                self.assertEqual(value, rank+1)
+                                self.assertEqual(value, rank + 1)
                             else:
                                 self.assertEqual(value, rank)
                         else:
@@ -502,36 +527,38 @@ class BaseTestCCOBufInplace:
                                 if redval < max_val:
                                     self.assertAlmostEqual(value, redval)
                             elif op == MPI.PROD:
-                                redval = prod(range(1,size+1))
+                                redval = prod(range(1, size + 1))
                                 if redval < max_val:
                                     self.assertAlmostEqual(value, redval)
                             elif op == MPI.MAX:
-                                self.assertEqual(value, size-1)
+                                self.assertEqual(value, size - 1)
                             elif op == MPI.MIN:
                                 self.assertEqual(value, 0)
 
-    @unittest.skipMPI('openmpi(<=1.8.6)')
+    @unittest.skipMPI("openmpi(<=1.8.6)")
     def testReduceScatter(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.MAX, MPI.MIN, MPI.PROD):
-                if skip_op(typecode, op): continue
-                rcnt = list(range(1, size+1))
+                if skip_op(typecode, op):
+                    continue
+                rcnt = list(range(1, size + 1))
                 if op == MPI.PROD:
-                    rbuf = array([rank+1]*sum(rcnt), typecode)
+                    rbuf = array([rank + 1] * sum(rcnt), typecode)
                 else:
-                    rbuf = array([rank]*sum(rcnt), typecode)
-                self.COMM.Ireduce_scatter(MPI.IN_PLACE,
-                                          rbuf.as_mpi(),
-                                          rcnt, op).Wait()
+                    rbuf = array([rank] * sum(rcnt), typecode)
+                self.COMM.Ireduce_scatter(
+                    MPI.IN_PLACE, rbuf.as_mpi(), rcnt, op
+                ).Wait()
                 max_val = maxvalue(rbuf)
                 for i, value in enumerate(rbuf):
                     if i >= rcnt[rank]:
                         if op == MPI.PROD:
-                            self.assertEqual(value, rank+1)
+                            self.assertEqual(value, rank + 1)
                         else:
                             self.assertEqual(value, rank)
                     else:
@@ -540,28 +567,28 @@ class BaseTestCCOBufInplace:
                             if redval < max_val:
                                 self.assertAlmostEqual(value, redval)
                         elif op == MPI.PROD:
-                            redval = prod(range(1,size+1))
+                            redval = prod(range(1, size + 1))
                             if redval < max_val:
                                 self.assertAlmostEqual(value, redval)
                         elif op == MPI.MAX:
-                            self.assertEqual(value, size-1)
+                            self.assertEqual(value, size - 1)
                         elif op == MPI.MIN:
                             self.assertEqual(value, 0)
 
-    @unittest.skipMPI('openmpi(<=1.8.4)')
+    @unittest.skipMPI("openmpi(<=1.8.4)")
     def testScan(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         # --
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.PROD, MPI.MAX, MPI.MIN):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 buf = array(range(size), typecode)
-                self.COMM.Iscan(MPI.IN_PLACE,
-                                buf.as_mpi(),
-                                op).Wait()
+                self.COMM.Iscan(MPI.IN_PLACE, buf.as_mpi(), op).Wait()
                 max_val = maxvalue(buf)
                 for i, value in enumerate(buf):
                     if op == MPI.SUM:
@@ -575,22 +602,22 @@ class BaseTestCCOBufInplace:
                     elif op == MPI.MIN:
                         self.assertEqual(value, i)
 
-    @unittest.skipMPI('openmpi(<=1.8.4)')
+    @unittest.skipMPI("openmpi(<=1.8.4)")
     def testExscan(self):
         size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             # segfault as of OpenMPI 4.1.1
-            if unittest.is_mpi_gpu('openmpi', array): continue
+            if unittest.is_mpi_gpu("openmpi", array):
+                continue
             for op in (MPI.SUM, MPI.PROD, MPI.MAX, MPI.MIN):
-                if skip_op(typecode, op): continue
+                if skip_op(typecode, op):
+                    continue
                 buf = array(range(size), typecode)
                 try:
-                    self.COMM.Iexscan(MPI.IN_PLACE,
-                                      buf.as_mpi(),
-                                      op).Wait()
+                    self.COMM.Iexscan(MPI.IN_PLACE, buf.as_mpi(), op).Wait()
                 except NotImplementedError:
-                    self.skipTest('mpi-exscan')
+                    self.skipTest("mpi-exscan")
                 if rank == 1:
                     for i, value in enumerate(buf):
                         self.assertEqual(value, i)
@@ -601,8 +628,8 @@ class BaseTestCCOBufInplace:
                             if (i * rank) < max_val:
                                 self.assertAlmostEqual(value, i * rank)
                         elif op == MPI.PROD:
-                            if (i ** rank) < max_val:
-                                self.assertAlmostEqual(value, i ** rank)
+                            if (i**rank) < max_val:
+                                self.assertAlmostEqual(value, i**rank)
                         elif op == MPI.MAX:
                             self.assertEqual(value, i)
                         elif op == MPI.MIN:
@@ -610,29 +637,43 @@ class BaseTestCCOBufInplace:
 
 
 class TestCCOBufSelf(BaseTestCCOBuf, unittest.TestCase):
+    #
     COMM = MPI.COMM_SELF
 
+
 class TestCCOBufWorld(BaseTestCCOBuf, unittest.TestCase):
+    #
     COMM = MPI.COMM_WORLD
 
+
 class TestCCOBufInplaceSelf(BaseTestCCOBufInplace, unittest.TestCase):
+    #
     COMM = MPI.COMM_SELF
 
+
 class TestCCOBufInplaceWorld(BaseTestCCOBufInplace, unittest.TestCase):
+    #
     COMM = MPI.COMM_WORLD
-    @unittest.skipMPI('mvapich(<3.0.0)', MPI.COMM_WORLD.Get_size() > 1)
+
+    @unittest.skipMPI("mvapich(<3.0.0)", MPI.COMM_WORLD.Get_size() > 1)
     def testReduceScatter(self):
         super().testReduceScatter()
 
+
 class TestCCOBufSelfDup(TestCCOBufSelf):
+    #
     def setUp(self):
         self.COMM = MPI.COMM_SELF.Dup()
+
     def tearDown(self):
         self.COMM.Free()
 
+
 class TestCCOBufWorldDup(TestCCOBufWorld):
+    #
     def setUp(self):
         self.COMM = MPI.COMM_WORLD.Dup()
+
     def tearDown(self):
         self.COMM.Free()
 
@@ -640,9 +681,9 @@ class TestCCOBufWorldDup(TestCCOBufWorld):
 try:
     MPI.COMM_SELF.Ibarrier().Wait()
 except NotImplementedError:
-    unittest.disable(BaseTestCCOBuf, 'mpi-nbc')
-    unittest.disable(BaseTestCCOBufInplace, 'mpi-nbc')
+    unittest.disable(BaseTestCCOBuf, "mpi-nbc")
+    unittest.disable(BaseTestCCOBufInplace, "mpi-nbc")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
