@@ -1,20 +1,31 @@
-from mpi4py import MPI
-import mpiunittest as unittest
+import sys
 import threading
 import warnings
-import sys
+
+import mpiunittest as unittest
+
+from mpi4py import MPI
+
 
 def allocate(n):
     return bytearray(n)
 
+
 _basic = [
     None,
-    True, False,
-    -7, 0, 7,
-    -2**63+1, 2**63-1,
-    -2.17, 0.0, 3.14,
-    1+2j, 2-3j,
-    'mpi4py',
+    True,
+    False,
+    -7,
+    0,
+    7,
+    -(2**63) + 1,
+    2**63 - 1,
+    -2.17,
+    0.0,
+    +1.62,
+    1 + 2j,
+    2 - 3j,
+    "mpi4py",
 ]
 messages = list(_basic)
 messages += [
@@ -22,11 +33,12 @@ messages += [
     tuple(_basic),
     set(_basic),
     frozenset(_basic),
-    {f'k{k}': v for k, v in enumerate(_basic)},
+    {f"k{k}": v for k, v in enumerate(_basic)},
 ]
 
-class BaseTestP2PObj:
 
+class BaseTestP2PObj:
+    #
     COMM = MPI.COMM_NULL
 
     def testSendAndRecv(self):
@@ -36,16 +48,17 @@ class BaseTestP2PObj:
             self.COMM.send(smess, MPI.PROC_NULL)
             rmess = self.COMM.recv(None, MPI.PROC_NULL, 0)
             self.assertIsNone(rmess)
-        if size == 1: return
+        if size == 1:
+            return
         for smess in messages:
             if rank == 0:
-                self.COMM.send(smess, rank+1, 0)
+                self.COMM.send(smess, rank + 1, 0)
                 rmess = smess
             elif rank == size - 1:
-                rmess = self.COMM.recv(None, rank-1, 0)
+                rmess = self.COMM.recv(None, rank - 1, 0)
             else:
-                rmess = self.COMM.recv(None, rank-1, 0)
-                self.COMM.send(rmess, rank+1, 0)
+                rmess = self.COMM.recv(None, rank - 1, 0)
+                self.COMM.send(rmess, rank + 1, 0)
             self.assertEqual(rmess, smess)
 
     def testISendAndRecv(self):
@@ -71,8 +84,8 @@ class BaseTestP2PObj:
             self.assertFalse(req)
             self.assertEqual(rmess, smess)
         for smess in messages:
-            dst = (rank+1)%size
-            src = (rank-1)%size
+            dst = (rank + 1) % size
+            src = (rank - 1) % size
             req = self.COMM.isend(smess, dst, 0)
             self.assertTrue(req)
             rmess = self.COMM.recv(buf, src, 0)
@@ -102,15 +115,16 @@ class BaseTestP2PObj:
             comm.send(smess, rank, 0)
             self.assertTrue(req)
             flag, rmess = req.test()
-            while not flag: flag, rmess = req.test()
+            while not flag:
+                flag, rmess = req.test()
             self.assertTrue(flag)
             self.assertFalse(req)
             self.assertEqual(rmess, smess)
         tmp = allocate(1024)
         for buf in (None, 1024, tmp):
-            for smess in messages + [messages]:
-                dst = (rank+1)%size
-                src = (rank-1)%size
+            for smess in [*messages, messages]:
+                dst = (rank + 1) % size
+                src = (rank - 1) % size
                 req = comm.irecv(buf, src, 0)
                 self.assertTrue(req)
                 comm.send(smess, dst, 0)
@@ -125,7 +139,7 @@ class BaseTestP2PObj:
             rreqs = [rreq1, rreq2, rreq3]
             for i in range(len(rreqs)):
                 self.assertTrue(rreqs[i])
-                comm.send(smess, dst, i+1)
+                comm.send(smess, dst, i + 1)
                 index, obj = MPI.Request.waitany(rreqs)
                 self.assertEqual(index, i)
                 self.assertEqual(obj, smess)
@@ -145,7 +159,7 @@ class BaseTestP2PObj:
             self.assertIsNone(obj)
             for i in range(len(rreqs)):
                 self.assertTrue(rreqs[i])
-                comm.send(smess, dst, i+1)
+                comm.send(smess, dst, i + 1)
                 index, flag, obj = MPI.Request.testany(rreqs)
                 while not flag:
                     index, flag, obj = MPI.Request.testany(rreqs)
@@ -164,23 +178,23 @@ class BaseTestP2PObj:
         rank = comm.Get_rank()
         tmp = allocate(512)
         for smess in messages:
-            dst = (rank+1)%size
-            src = (rank-1)%size
+            dst = (rank + 1) % size
+            src = (rank - 1) % size
             rreq = comm.irecv(None, src, 0)
             self.assertTrue(rreq)
             sreq = comm.isend(smess, dst, 0)
             self.assertTrue(sreq)
-            index1, mess1 = MPI.Request.waitany([sreq,rreq])
+            index1, mess1 = MPI.Request.waitany([sreq, rreq])
             self.assertIn(index1, (0, 1))
             if index1 == 0:
                 self.assertFalse(sreq)
-                self.assertTrue (rreq)
+                self.assertTrue(rreq)
                 self.assertIsNone(mess1)
             else:
-                self.assertTrue (sreq)
+                self.assertTrue(sreq)
                 self.assertFalse(rreq)
                 self.assertEqual(mess1, smess)
-            index2, mess2 = MPI.Request.waitany([sreq,rreq])
+            index2, mess2 = MPI.Request.waitany([sreq, rreq])
             self.assertIn(index2, (0, 1))
             self.assertNotEqual(index2, index1)
             self.assertFalse(sreq)
@@ -190,27 +204,27 @@ class BaseTestP2PObj:
             else:
                 self.assertEqual(mess2, smess)
         for smess in messages:
-            dst = (rank+1)%size
-            src = (rank-1)%size
+            dst = (rank + 1) % size
+            src = (rank - 1) % size
             rreq = comm.irecv(None, src, 0)
             self.assertTrue(rreq)
             sreq = comm.isend(smess, dst, 0)
             self.assertTrue(sreq)
-            index1, flag1, mess1 = MPI.Request.testany([sreq,rreq])
+            index1, flag1, mess1 = MPI.Request.testany([sreq, rreq])
             while not flag1:
-                index1, flag1, mess1 = MPI.Request.testany([sreq,rreq])
+                index1, flag1, mess1 = MPI.Request.testany([sreq, rreq])
             self.assertIn(index1, (0, 1))
             if index1 == 0:
                 self.assertFalse(sreq)
-                self.assertTrue (rreq)
+                self.assertTrue(rreq)
                 self.assertIsNone(mess1)
             else:
-                self.assertTrue (sreq)
+                self.assertTrue(sreq)
                 self.assertFalse(rreq)
                 self.assertEqual(mess1, smess)
-            index2, flag2, mess2 = MPI.Request.testany([sreq,rreq])
+            index2, flag2, mess2 = MPI.Request.testany([sreq, rreq])
             while not flag2:
-                index2, flag2, mess2 = MPI.Request.testany([sreq,rreq])
+                index2, flag2, mess2 = MPI.Request.testany([sreq, rreq])
             self.assertIn(index2, (0, 1))
             self.assertNotEqual(index2, index1)
             self.assertFalse(sreq)
@@ -221,13 +235,13 @@ class BaseTestP2PObj:
                 self.assertEqual(mess2, smess)
         for buf in (None, 512, tmp):
             for smess in messages:
-                dst = (rank+1)%size
-                src = (rank-1)%size
+                dst = (rank + 1) % size
+                src = (rank - 1) % size
                 rreq = comm.irecv(buf, src, 0)
                 self.assertTrue(rreq)
                 sreq = comm.isend(smess, dst, 0)
                 self.assertTrue(sreq)
-                dummy, rmess = MPI.Request.waitall([sreq,rreq], [])
+                dummy, rmess = MPI.Request.waitall([sreq, rreq], [])
                 self.assertFalse(sreq)
                 self.assertFalse(rreq)
                 self.assertIsNone(dummy)
@@ -241,7 +255,7 @@ class BaseTestP2PObj:
                 self.assertIsNone(msg)
                 sreq = comm.isend(smess, dst, 1)
                 while True:
-                    flag, msg = MPI.Request.testall([sreq,rreq], [])
+                    flag, msg = MPI.Request.testall([sreq, rreq], [])
                     if not flag:
                         self.assertIsNone(msg)
                         continue
@@ -251,11 +265,10 @@ class BaseTestP2PObj:
                     break
 
     def testManyISendAndRecv(self):
-        size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for smess in messages:
             reqs = []
-            for k in range(6):
+            for _k in range(6):
                 r = self.COMM.isend(smess, rank, 0)
                 reqs.append(r)
             flag = MPI.Request.Testall(reqs)
@@ -265,7 +278,7 @@ class BaseTestP2PObj:
                     self.assertEqual(index, MPI.UNDEFINED)
                 indices = MPI.Request.Testsome(reqs)
                 self.assertIsInstance(indices, list)
-            for k in range(3):
+            for _k in range(3):
                 rmess = self.COMM.recv(None, rank, 0)
                 self.assertEqual(rmess, smess)
             flag = MPI.Request.Testall(reqs)
@@ -282,17 +295,17 @@ class BaseTestP2PObj:
                     indices = sorted(indices)
                 self.assertGreaterEqual(count, 2)
                 self.assertEqual(indices[:2], [1, 2])
-            for k in range(3):
+            for _k in range(3):
                 rmess = self.COMM.recv(None, rank, 0)
                 self.assertEqual(rmess, smess)
             flag = MPI.Request.Testall(reqs)
             self.assertTrue(flag)
         for smess in messages:
             reqs = []
-            for k in range(6):
+            for _k in range(6):
                 r = self.COMM.isend(smess, rank, 0)
                 reqs.append(r)
-            for k in range(3):
+            for _k in range(3):
                 rmess = self.COMM.recv(None, rank, 0)
                 self.assertEqual(rmess, smess)
             index = MPI.Request.Waitany(reqs)
@@ -303,7 +316,7 @@ class BaseTestP2PObj:
                 indices1 = []
             else:
                 count1 = len(indices1)
-            for k in range(3):
+            for _k in range(3):
                 rmess = self.COMM.recv(None, rank, 0)
                 self.assertEqual(rmess, smess)
             indices2 = MPI.Request.Waitsome(reqs)
@@ -312,25 +325,26 @@ class BaseTestP2PObj:
                 indices2 = []
             else:
                 count2 = len(indices2)
-            if count1 == MPI.UNDEFINED: count1 = 0
-            if count2 == MPI.UNDEFINED: count2 = 0
-            self.assertEqual(6, 1+count1+count2)
-            indices = [0]+list(indices1)+list(indices2)
+            if count1 == MPI.UNDEFINED:
+                count1 = 0
+            if count2 == MPI.UNDEFINED:
+                count2 = 0
+            self.assertEqual(6, 1 + count1 + count2)
+            indices = [0, *list(indices1), *list(indices2)]
             indices.sort()
             self.assertEqual(indices, list(range(6)))
             MPI.Request.Waitall(reqs)
 
     def testManyISSendAndRecv(self):
-        size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         for smess in messages:
             reqs = []
-            for k in range(6):
+            for _k in range(6):
                 r = self.COMM.issend(smess, rank, 0)
                 reqs.append(r)
             flag = MPI.Request.Testall(reqs)
             self.assertFalse(flag)
-            for k in range(3):
+            for _k in range(3):
                 rmess = self.COMM.recv(None, rank, 0)
                 self.assertEqual(rmess, smess)
             flag = MPI.Request.Testall(reqs)
@@ -345,16 +359,17 @@ class BaseTestP2PObj:
                     del target[0]
                 for index in indices:
                     self.assertIn(index, target)
-            for k in range(3):
+            for _k in range(3):
                 flag = MPI.Request.Testall(reqs)
                 self.assertFalse(flag)
                 rmess = self.COMM.recv(None, rank, 0)
                 self.assertEqual(rmess, smess)
             flag = False
-            for k in range(10):
+            for _k in range(10):
                 flag |= MPI.Request.Testall(reqs)
-                if flag: break
-            if unittest.is_mpi('impi') and sys.platform == 'win32':
+                if flag:
+                    break
+            if unittest.is_mpi("impi") and sys.platform == "win32":
                 flag |= MPI.Request.Waitall(reqs)
             self.assertTrue(flag)
 
@@ -365,16 +380,17 @@ class BaseTestP2PObj:
             self.COMM.ssend(smess, MPI.PROC_NULL)
             rmess = self.COMM.recv(None, MPI.PROC_NULL, 0)
             self.assertIsNone(rmess)
-        if size == 1: return
+        if size == 1:
+            return
         for smess in messages:
             if rank == 0:
-                self.COMM.ssend(smess, rank+1, 0)
+                self.COMM.ssend(smess, rank + 1, 0)
                 rmess = smess
             elif rank == size - 1:
-                rmess = self.COMM.recv(None, rank-1, 0)
+                rmess = self.COMM.recv(None, rank - 1, 0)
             else:
-                rmess = self.COMM.recv(None, rank-1, 0)
-                self.COMM.ssend(rmess, rank+1, 0)
+                rmess = self.COMM.recv(None, rank - 1, 0)
+                self.COMM.ssend(rmess, rank + 1, 0)
             self.assertEqual(rmess, smess)
 
     def testISSendAndRecv(self):
@@ -402,8 +418,8 @@ class BaseTestP2PObj:
             self.assertFalse(req)
             self.assertEqual(rmess, smess)
         for smess in messages:
-            dst = (rank+1)%size
-            src = (rank-1)%size
+            dst = (rank + 1) % size
+            src = (rank - 1) % size
             req = self.COMM.issend(smess, dst, 0)
             self.assertTrue(req)
             rmess = self.COMM.recv(None, src, 0)
@@ -412,7 +428,6 @@ class BaseTestP2PObj:
             self.assertEqual(rmess, smess)
 
     def testCancel(self):
-        size = self.COMM.Get_size()
         rank = self.COMM.Get_rank()
         status = MPI.Status()
         for smess in messages:
@@ -430,7 +445,8 @@ class BaseTestP2PObj:
                 self.assertFalse(flag)
                 rmess = self.COMM.recv(None, rank, 0)
                 flag = req.get_status()
-                while not flag: flag = req.get_status()
+                while not flag:
+                    flag = req.get_status()
                 self.assertTrue(flag)
                 self.assertTrue(req)
                 flag, _ = req.test()
@@ -441,7 +457,7 @@ class BaseTestP2PObj:
     def testIRecvAndBSend(self):
         comm = self.COMM
         rank = comm.Get_rank()
-        buf = MPI.Alloc_mem((1<<16)+MPI.BSEND_OVERHEAD)
+        buf = MPI.Alloc_mem((1 << 16) + MPI.BSEND_OVERHEAD)
         MPI.Attach_buffer(buf)
         try:
             for smess in messages:
@@ -463,7 +479,7 @@ class BaseTestP2PObj:
     def testIRecvAndIBSend(self):
         comm = self.COMM
         rank = comm.Get_rank()
-        buf = MPI.Alloc_mem((1<<16)+MPI.BSEND_OVERHEAD)
+        buf = MPI.Alloc_mem((1 << 16) + MPI.BSEND_OVERHEAD)
         MPI.Attach_buffer(buf)
         try:
             for smess in messages:
@@ -522,40 +538,39 @@ class BaseTestP2PObj:
         for smess in messages:
             dest = (rank + 1) % size
             source = (rank - 1) % size
-            rmess = self.COMM.sendrecv(smess, dest,   0,
-                                       None,  source, 0)
+            rmess = self.COMM.sendrecv(smess, dest, 0, None, source, 0)
             continue
             self.assertEqual(rmess, smess)
-            rmess = self.COMM.sendrecv(None, dest,   0,
-                                       None, source, 0)
+            rmess = self.COMM.sendrecv(None, dest, 0, None, source, 0)
             self.assertIsNone(rmess)
-            rmess = self.COMM.sendrecv(smess, MPI.PROC_NULL, 0,
-                                       None,  MPI.PROC_NULL, 0)
+            rmess = self.COMM.sendrecv(
+                smess, MPI.PROC_NULL, 0, None, MPI.PROC_NULL, 0
+            )
             self.assertIsNone(rmess)
 
     def testMixed(self):
         comm = self.COMM
         rank = comm.Get_rank()
         #
-        sreq = comm.Isend([None, 0, 'B'], rank)
+        sreq = comm.Isend([None, 0, "B"], rank)
         obj = comm.recv(None, rank)
         sreq.Wait()
         self.assertIsNone(obj)
         for smess in messages:
             buf = MPI.pickle.dumps(smess)
-            sreq = comm.Isend([buf, 'B'], rank)
+            sreq = comm.Isend([buf, "B"], rank)
             rmess = comm.recv(None, rank)
             sreq.Wait()
             self.assertEqual(rmess, smess)
         #
-        sreq = comm.Isend([None, 0, 'B'], rank)
+        sreq = comm.Isend([None, 0, "B"], rank)
         rreq = comm.irecv(None, rank)
         sreq.Wait()
         obj = rreq.wait()
         self.assertIsNone(obj)
         for smess in messages:
             buf = MPI.pickle.dumps(smess)
-            sreq = comm.Isend([buf, 'B'], rank)
+            sreq = comm.Isend([buf, "B"], rank)
             rreq = comm.irecv(None, rank)
             sreq.Wait()
             rmess = rreq.wait()
@@ -568,29 +583,30 @@ class BaseTestP2PObj:
             self.COMM.send(smess, MPI.PROC_NULL)
             rmess = self.COMM.recv(None, MPI.PROC_NULL, 0)
             self.assertIsNone(rmess)
-        if size == 1: return
+        if size == 1:
+            return
         smess = None
         if rank == 0:
-            self.COMM.send(smess, rank+1, 0)
-            rmess = self.COMM.recv(None, rank+1, 0)
+            self.COMM.send(smess, rank + 1, 0)
+            rmess = self.COMM.recv(None, rank + 1, 0)
         elif rank == 1:
-            rmess = self.COMM.recv(None, rank-1, 0)
-            self.COMM.send(smess, rank-1, 0)
+            rmess = self.COMM.recv(None, rank - 1, 0)
+            self.COMM.send(smess, rank - 1, 0)
         else:
             rmess = smess
         self.assertEqual(rmess, smess)
         for smess in messages:
             if rank == 0:
-                self.COMM.send(smess, rank+1, 0)
-                rmess = self.COMM.recv(None, rank+1, 0)
+                self.COMM.send(smess, rank + 1, 0)
+                rmess = self.COMM.recv(None, rank + 1, 0)
             elif rank == 1:
-                rmess = self.COMM.recv(None, rank-1, 0)
-                self.COMM.send(smess, rank-1, 0)
+                rmess = self.COMM.recv(None, rank - 1, 0)
+                self.COMM.send(smess, rank - 1, 0)
             else:
                 rmess = smess
             self.assertEqual(rmess, smess)
 
-    @unittest.skipMPI('MPICH1')
+    @unittest.skipMPI("MPICH1")
     def testProbe(self):
         comm = self.COMM.Dup()
         try:
@@ -600,7 +616,8 @@ class BaseTestP2PObj:
             for smess in messages:
                 request = comm.issend(smess, comm.rank, 123)
                 self.assertTrue(request)
-                while not comm.iprobe(MPI.ANY_SOURCE, MPI.ANY_TAG, status): pass
+                while not comm.iprobe(MPI.ANY_SOURCE, MPI.ANY_TAG, status):
+                    pass
                 self.assertEqual(status.source, comm.rank)
                 self.assertEqual(status.tag, 123)
                 comm.probe(MPI.ANY_SOURCE, MPI.ANY_TAG, status)
@@ -624,13 +641,13 @@ class BaseTestP2PObj:
         comm = self.COMM.Dup()
         rank = comm.Get_rank()
         reqs = [comm.irecv(source=rank, tag=i) for i in range(6)]
-        for indexlist in ([5], [3,1,2], [0,4]):
+        for indexlist in ([5], [3, 1, 2], [0, 4]):
             for i in indexlist:
                 comm.ssend("abc", dest=rank, tag=i)
             statuses = []
             idxs, objs = MPI.Request.waitsome(reqs, statuses)
             self.assertEqual(sorted(idxs), sorted(indexlist))
-            self.assertEqual(objs, ["abc"]*len(idxs))
+            self.assertEqual(objs, ["abc"] * len(idxs))
             self.assertFalse(any(reqs[i] for i in idxs))
             self.assertEqual(len(statuses), len(idxs))
             self.assertTrue(all(s.source == rank for s in statuses))
@@ -652,13 +669,13 @@ class BaseTestP2PObj:
         self.assertEqual(objs, [])
         self.assertTrue(all(reqs))
         self.assertEqual(statuses, [])
-        for indexlist in ([5], [], [3,1,2], [], [0,4]):
+        for indexlist in ([5], [], [3, 1, 2], [], [0, 4]):
             for i in indexlist:
                 comm.ssend("abc", dest=rank, tag=i)
             statuses = []
             idxs, objs = MPI.Request.testsome(reqs, statuses)
             self.assertEqual(sorted(idxs), sorted(indexlist))
-            self.assertEqual(objs, ["abc"]*len(idxs))
+            self.assertEqual(objs, ["abc"] * len(idxs))
             self.assertFalse(any(reqs[i] for i in idxs))
             self.assertEqual(len(statuses), len(idxs))
             self.assertTrue(all(s.source == rank for s in statuses))
@@ -674,7 +691,7 @@ class BaseTestP2PObj:
         comm = self.COMM.Dup()
         rank = comm.Get_rank()
         reqs = [comm.issend("abc", dest=rank, tag=i) for i in range(6)]
-        for indexlist in ([5], [3,1,2], [0,4]):
+        for indexlist in ([5], [3, 1, 2], [0, 4]):
             for i in indexlist:
                 msg = comm.recv(source=rank, tag=i)
                 self.assertEqual(msg, "abc")
@@ -684,7 +701,7 @@ class BaseTestP2PObj:
                 idxs.extend(i)
                 objs.extend(o)
             self.assertEqual(sorted(idxs), sorted(indexlist))
-            self.assertEqual(objs, [None]*len(idxs))
+            self.assertEqual(objs, [None] * len(idxs))
             self.assertFalse(any(reqs[i] for i in idxs))
         idxs, objs = MPI.Request.waitsome(reqs)
         self.assertIsNone(idxs)
@@ -700,7 +717,7 @@ class BaseTestP2PObj:
         self.assertEqual(idxs, [])
         self.assertEqual(objs, [])
         self.assertTrue(all(reqs))
-        for indexlist in ([5], [], [3,1,2], [], [0,4]):
+        for indexlist in ([5], [], [3, 1, 2], [], [0, 4]):
             for i in indexlist:
                 msg = comm.recv(source=rank, tag=i)
                 self.assertEqual(msg, "abc")
@@ -710,7 +727,7 @@ class BaseTestP2PObj:
                 idxs.extend(i)
                 objs.extend(o)
             self.assertEqual(sorted(idxs), sorted(indexlist))
-            self.assertEqual(objs, [None]*len(idxs))
+            self.assertEqual(objs, [None] * len(idxs))
             self.assertFalse(any(reqs[i] for i in idxs))
         idxs, objs = MPI.Request.testsome(reqs)
         self.assertIsNone(idxs)
@@ -739,35 +756,43 @@ class BaseTestP2PObj:
         comm = self.COMM.Dup()
         table = MPI._comm_lock_table(comm)
         self.assertIsInstance(table, dict)
-        self.assertNotIn('bcast', table)
+        self.assertNotIn("bcast", table)
         comm.bcast(None, root=0)
-        self.assertIn('bcast', table)
-        lock = table['bcast']
+        self.assertIn("bcast", table)
+        lock = table["bcast"]
         lock_type = type(threading.Lock())
         self.assertIsInstance(lock, lock_type)
         comm.Free()
 
 
 class TestP2PObjSelf(BaseTestP2PObj, unittest.TestCase):
+    #
     COMM = MPI.COMM_SELF
 
+
 class TestP2PObjWorld(BaseTestP2PObj, unittest.TestCase):
+    #
     COMM = MPI.COMM_WORLD
 
+
 class TestP2PObjSelfDup(TestP2PObjSelf):
+    #
     def setUp(self):
         self.COMM = MPI.COMM_SELF.Dup()
+
     def tearDown(self):
         self.COMM.Free()
 
-@unittest.skipMPI('openmpi(<1.4.0)', MPI.Query_thread() > MPI.THREAD_SINGLE)
+
+@unittest.skipMPI("openmpi(<1.4.0)", MPI.Query_thread() > MPI.THREAD_SINGLE)
 class TestP2PObjWorldDup(TestP2PObjWorld):
+    #
     def setUp(self):
         self.COMM = MPI.COMM_WORLD.Dup()
+
     def tearDown(self):
         self.COMM.Free()
 
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
